@@ -1,13 +1,13 @@
-# Copyrights 2011-2015 by [Mark Overmeer].
+# Copyrights 2011-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::WSS::BasicAuth;
 use vars '$VERSION';
-$VERSION = '1.13';
+$VERSION = '1.14';
 
 use base 'XML::Compile::WSS';
 
@@ -35,12 +35,12 @@ sub init($)
     $self->{XCWB_password} = $args->{password}
         or error __x"no password provided for basic authentication";
 
-    my $n     = defined $args->{nonce} ? $args->{nonce} : 'RANDOM';
+    my $n     = $args->{nonce};
     my $nonce = ref $n eq 'CODE' ? $n
-              : $n eq 'RANDOM'   ? \&_random_nonce
-              :                    sub { $n };
+              : defined $n && $n eq 'RANDOM' ? \&_random_nonce
+              :    sub { $n };
 
-    $self->{XCWB_nonce}    = $args->{nonce};
+    $self->{XCWB_nonce}    = $nonce;
     $self->{XCWB_wsu_id}   = $args->{wsu_Id}   || $args->{wsu_id};
     $self->{XCWB_created}  = $args->{created};
     $self->{XCWB_pwformat} = $args->{pwformat} || UTP11_PTEXT;
@@ -51,7 +51,7 @@ sub init($)
 
 sub username() {shift->{XCWB_username}}
 sub password() {shift->{XCWB_password}}
-sub nonce()    {shift->{XCWB_nonce}   }
+sub nonce()    {shift->{XCWB_nonce}->() }
 sub wsuId()    {shift->{XCWB_wsu_id}  }
 sub created()  {shift->{XCWB_created} }
 sub pwformat() {shift->{XCWB_pwformat}}
